.. _utilipy-utils-collections:

*****************************************
collections (`utilipy.utils.collections`)
*****************************************

.. currentmodule:: utilipy.utils.collections


Reference/API
=============

.. automodapi:: utilipy.utils.collections
